@@ -22,7 +22,8 @@ class AsyncClient(client.Client):
 
     :param logger: To enable logging set to ``True`` or pass a logger object to
                    use. To disable logging set to ``False``. The default is
-                   ``False``.
+                   ``False``. Note that fatal errors are logged even when
+                   ``logger`` is ``False``.
     :param json: An alternative json module to use for encoding and decoding
                  packets. Custom json modules must have ``dumps`` and ``loads``
                  functions that are compatible with the standard library
@@ -239,6 +240,20 @@ class AsyncClient(client.Client):
             self.logger.info(
                 'Attempting WebSocket connection to ' + websocket_url)
 
+        if self.http is None or self.http.closed:  # pragma: no cover
+            self.http = aiohttp.ClientSession()
+
+        # extract any new cookies passed in a header so that they can also be
+        # sent the the WebSocket route
+        cookies = {}
+        for header, value in headers.items():
+            if header.lower() == 'cookie':
+                cookies = dict(
+                    [cookie.split('=') for cookie in value.split('; ')])
+                del headers[header]
+                break
+        self.http.cookie_jar.update_cookies(cookies)
+
         try:
             if not self.ssl_verify:
                 ssl_context = ssl.create_default_context()
@@ -482,6 +497,8 @@ class AsyncClient(client.Client):
             p = None
             try:
                 p = (await self.ws.receive()).data
+                if p is None:  # pragma: no cover
+                    raise RuntimeError('WebSocket read returned None')
             except aiohttp.client_exceptions.ServerDisconnectedError:
                 self.logger.info(
                     'Read loop: WebSocket connection was closed, aborting')
